# Datasets Module / データセットモジュール

The `wandas.datasets` module provides sample data that can be used for testing and demonstrations.
`wandas.datasets` モジュールは、テストやデモに使用できるサンプルデータを提供します。

## Sample Data / サンプルデータ

Provides sample audio data that can be used for testing and demonstrations.
テストやデモで使用できるサンプルオーディオデータを提供します。

::: wandas.datasets.sample_data
